# eric7.DataViews.PyCoverageJsonReportDialog

Module implementing a dialog to enter the parameters for a coverage JSON report.

### Global Attributes

None

### Classes

PyCoverageJsonReportDialog | Class implementing a dialog to enter the parameters for a coverage JSON report.

### Functions

None

## PyCoverageJsonReportDialog

Class implementing a dialog to enter the parameters for a coverage JSON report.

### Derived from

QDialog, Ui_PyCoverageJsonReportDialog

### Class Attributes

None

### Class Methods

None

### Methods

PyCoverageJsonReportDialog | Constructor
getData | Public method to get the entered data.
on_outputFilePicker_textChanged | Private slot handling a change of the output file.

### Static Methods

None

#### PyCoverageJsonReportDialog (Constructor)

PyCoverageJsonReportDialog(defaultDirectory, parent=None)

Constructor

defaultDirectory (str)
  default directory for selecting the output directory
parent (QWidget (optional))
  reference to the parent widget (defaults to None)

#### PyCoverageJsonReportDialog.getData

getData()

Public method to get the entered data.

Return:
  tuple containing the output file and a flag indicating the creation of a compact JSON file

Return Type:
  tuple of (str, bool)

#### PyCoverageJsonReportDialog.on_outputFilePicker_textChanged

on_outputFilePicker_textChanged(filename)

Private slot handling a change of the output file.

filename (str)
  current text of the file picker

Up